@@ -244,6 +244,7 @@ Ext.ux.MultiFilter.Plugin = Ext.extend(Ext.util.Observable,{
 			xtype: 'button',
 			text: 'Save and Close',
 			iconCls: 'ra-icon-save-ok',
+      scope: this,
 			handler: function(btn) {
 				var win = btn.ownerCt.ownerCt;
 				var set = win.getComponent('filSet');
@@ -254,7 +255,7 @@ Ext.ux.MultiFilter.Plugin = Ext.extend(Ext.util.Observable,{
 				
 				win.multifilter.updateFilterBtn();
 				
-				win.close();
+        win.hide(this.filtersBtn.el,win.close,win);
         
         // Added for Github Issue #20 (and copied from Quick Search code)
         // clear start (necessary if we have paging) - resets to page 1
@@ -280,7 +281,8 @@ Ext.ux.MultiFilter.Plugin = Ext.extend(Ext.util.Observable,{
 			anchor: '-0',
 			style: 'padding:2px;',
 			buttonAlign: 'center',
-			buttons: hbuttons
+			buttons: hbuttons,
+      hidden: true // start hidden; will be toggled visible when frozen conditions exist
 		});
 		
     // -- NEW: Set the window size taking the active 
@@ -302,7 +304,6 @@ Ext.ux.MultiFilter.Plugin = Ext.extend(Ext.util.Observable,{
     // --
     
 		var win = new Ext.Window({
-		
 			//id: 'mywin',
 			multifilter: this,
 			title: 'MultiFilter',
@@ -326,19 +327,21 @@ Ext.ux.MultiFilter.Plugin = Ext.extend(Ext.util.Observable,{
 				})
 			],
 			buttons: buttons,
-			buttonAlign: button_Align
+			buttonAlign: button_Align,
+      smartRenderTo: this.grid
 		});
 		
-		win.show();
-		
-		var set = win.getComponent('filSet');
-		set.loadData(this.store.filterdata || []);
-		set.filterdata_frozen = this.store.filterdata_frozen || [];
-		set.on('remove',update_selections.createDelegate(this,[set]),this);
-		set.on('add',update_selections.createDelegate(this,[set]),this,{ buffer: 20 });
+    // Move into show callback to avoid race condition:
+    win.show(this.filtersBtn.el,function(){
+      var set = win.getComponent('filSet');
+      set.loadData(this.store.filterdata || []);
+      set.filterdata_frozen = this.store.filterdata_frozen || [];
+      set.on('remove',update_selections.createDelegate(this,[set]),this);
+      set.on('add',update_selections.createDelegate(this,[set]),this,{ buffer: 20 });
+
+      update_selections(set);
+    },this);
 
-		update_selections(set);
-		
 		return win;
 	}
 });
@@ -1046,6 +1049,8 @@ Ext.reg('filteritem',Ext.ux.MultiFilter.Filter);
 
 Ext.ux.MultiFilter.FilterSetPanel = Ext.extend(Ext.Panel,{
 
+  border: false,
+
 	autoHeight: true,
 	
 	FilterParams: {},
